import PropTypes from "prop-types";
import React from "react";
import { View, StyleSheet, Text } from "react-native";
import jsdiff from "diff";

const fnMap = {
  chars: jsdiff.diffChars,
  words: jsdiff.diffWords,
  sentences: jsdiff.diffSentences,
  json: jsdiff.diffJson
};

export default function Diff({
  inputA = "",
  inputB = "",
  type = "chars",
  textStyle = {},
  containerStyle = {}
}) {
  var diff = fnMap[type](inputA, inputB);
  var result = diff.map(function(part, index) {
    var spanStyle = {
      backgroundColor: part.added
        ? "lightgreen"
        : part.removed
        ? "salmon"
        : "lightgrey"
    };
    return (
      <Text key={index} style={[spanStyle, textStyle]}>
        {part.value}
      </Text>
    );
  });
  return (
    <View style={[styles.defaultContainerStyle, containerStyle]}>{result}</View>
  );
}

Diff.propTypes = {
  inputA: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  inputB: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  type: PropTypes.oneOf(["chars", "words", "sentences", "json"]),
  textStyle: PropTypes.object,
  containerStyle: PropTypes.object
};

const styles = StyleSheet.create({
  defaultContainerStyle: {}
});
